# Unit 2: Biology

## Cellular Biology
A person contains roughly 100 trillion cells
- Cells are roughly 20 `μm` (micrometre, 10<sup>-6</sup> m), around 250 cells / cm

## Cell Theory
1. All living things are composed of cells 
2. Cells are the basic units of living organisms
3. All cells came from pre-existing cells

## Eukaryotic versus Prokaryotic Cells
`Prokaryotic cell`: Meaning before/lacking nucleus

`Eukaryotic cell`: Means complete nucleus

|Factors|Prokaryotic|Eukaryotic|
|:-----------|:----------|:---------|
|DNA|In nucleoid region|Usually in membrane-bound nucleus|
|Size|Usually smaller|Usually larger|
|Organelles|Not membrane-bound, smaller|Membrane-bound, more complex|
|Organization|Usually singlecelled|Often form multicellular organisms|
|Metabolism|May not need oxygen|Usually need oxygen|

## Cellular Organelles

### Business Analogy

| In a business | In a cell | 
| ------------- | --------- |
| Building      | Cytoplasm & Cytoskeleton |
| Department Head | Organelles |
| Boss          | DNA |
| Workers       | Ribosomes & Enzymes |
| Waste management | Lysosomes |
| Storage       | Vacuoles | 
| Powerhouse    | Chloroplasts & Mitochondria |
| Security gate | Cell membrane controls entrance and exit from the cell |
| Transportation Department | IMPORT: Cell membranes and vesicles, INTERNAL: Endoplasmic reticulum & vesicles, EXPORT: Golgi apparatus, vesicles, and cell membrane |


### Cell Membrane
- Controls what substances **enter/leave** the cell selectively via various receptors/osmosis
    - Allows **nutrients** to enter
    - Allows **waste products** to leave (removal of waste)
- Surrounds and holds other organelles in cell
- Interact with outside chemicals (e.g., hormones)
- Transports food and nutrients into the cell

### Nucleus
- Is the control center of the cell
- Holds deoxyribonucleic acid (DNA) in form of `chromatin`
    - DNA is a double helix containing genes
        - `Genes`: any section of DNA that contains a full set of instructions to make either RNA or a protein, **found** in nucleus
    - `Chromatin`: is DNA **wrapped tightly** in protein
- `Chromosomes`: are even more tightly wrapped `chromatin` used in cell division only, formed when `DNA` **condenses** in `mitosis`
- Surrounded by a double membrane
- Substances enter and exit the nucleus via `nuclear pores`. `Nuclear pores` are holes in the membrane that allow `proteins` and `nucleic acids` into the `cytoplasm`
- Messenger RNA (mRNA) is encoded from DNA and sent to `ribosomes` to produce proteins
- Humans have ~2 meters of genes per cell per nucleus tightly wrapped


### Nucleolus
 - Dense region of DNA located in the nucleus
 - This area of DNA is specially for ribosomal DNA (rDNA), or DNA used to code `ribosomes`, enzymes that assemble proteins
 - Produce "large" and "small" subunits of `ribosomes`, which either form complete `ribosomes` in `cytosol` or mix with `endoplasmic reticulum`, forming `rough endoplasmic reticulum` (RER)

### Cytoplasm & Cytosol
 - `Cytosol` is the fluid cells contain
 - **All organelles** are suspended in `cytosol`
 - `Cytoplasm` is the `cytosol` along with everything in a cell, excluding the nucleus

## Endoplasmic Reticulum
- The endoplasmic reticulum is a network of `tubules` and **flattened sacs** with a <b>*rough*</b> appearance because of the presence of `ribosomes` on the surface
- Network of tubules and flattened sacs
- **Transports** proteins via cytoskeleton in vesicles

## Specific to Rough ER
- Appears "rough" due to the `ribosomes` attached to its outer surface
- Located directly adjacent and attached to nucleus
- Located next to `Golgi apparatus`
- `Ribosomes` in rough ER **synthesize proteins**
    - Transports synthesized proteins to `Golgi apparatus` for packaging and distribution
    - About half the cell's proteins are produced here
- Folds, fixes and **modifies both newly-created and pre-existing proteins** somewhat like **proof-reading**

## Specific to Smooth ER
- **Does not** synthesize proteins
- Appears "smooth" due to lack of `ribosomes`
- Located directly adjacent and attached to nucleus
- Synthesizes lipids (fats, e.g., cholesterol)
- **Metabolises** carbohydrates

## Golgi Apparatus
- Also known as Golgi body, Golgi complex, etc.
- **Receives, modifies and transports** proteins that were produced by the rough ER
- **Packages** proteins into `vesicles` and sends them `cell membrane` for export

## Lysosome
- Spherical vesicle that containing `enzymes`
- **Digests and kills** foreign matter which is then excreted
     - E.g., white blood cells use lysosomes to kill bacteria then spit it out
- **Digests and breaks down** old and unused material/non-functional organelles as needed
- If lysosome ruptures everything dies, hence they are known as "suicude sacs"

## Mitochondria
 - **Singular form is "mitochondrion"**
 - Contains an inner and outer membrane
 - Processes glucose + oxygen gas to form carbon dioxide + adenosine triphosphate (ATP)
    - ATP allows proteins to do things (e.g., spend 1 ATP break 1 molecule)
    - ATP cannot be stored
    - ATP is needed for daily function of the cell

## Cytoskeleton
- Made of **protein filaments**
- **Maintains** and **changes** cell structure, much like a human skeleton + muscular system
    - Moves cells
    - Modifies and adjusts cell structure as needed
- Chemicals can travel along `cytoskeleton`, e.g., `organelles`, `vesicles`, etc.

## Organelles specific to animal cells
1. Centrioles and centrosomes
2. Lysosomes

### Centrosomes
 - Made of same protein as `cytoskeleton`
 - Crucial to mitosis in animal cells
 - **Create and manipulate spindle fibres** during mitosis in animal cells

### Lysosomes
- Explained before.

## Organelles specific to plant cells
1. Cell wall
2. Chloroplast
3. Central Vacuole

### Cell wall
- Provides **structure** and prevents **cell rupture**
- A more stronger, thicker, rigit version of the `cell membrane`
- Made of **cellulose** (type of sugar)
- Also present in most bacteria, fungi, and protists
- The antibotic **penicillin** works by destroying the cell walls of bacteria, killing it

### Chloroplast
- The **solar panel** of the plant cell
- Conducts **photosynthesis**
- All chlorophyll is located in chloroplasts
- Looks green
- Parts of the plant that do not photosynthesize do not have chloroplasts

### Central Vacuole
- Extremely large, may take up to 90% of volume in cell
- Contains water
- Maintains `turgor` pressure against cell wall (pushes against cell wall in all directions)
- Maintains cell shape and resistance
    - Plant cells that lack **turgor pressure** (e.g., celery left in fridge) become **flaccid**

## Cell Division

### Purpose 

### 1. Reproduction
 - Single-cellular organisms reproduce via division **asexually**
 - Multicellular organisms reproduce via combining two germ cells ("sex cells") that contain half the DNA each of two organisms
    - This is **sexual**

### 2. Growth
 - Cells have maximum size before transportation of substances within cell becomes **inefficient**, due to **larger cells** decreasing efficiency of `diffusion`
 - Cells transport chemicals (e.g., nutrients) via `diffusion`, this **limits cell size**
 - The only way to maintain proper function and get bigger is to **add more cells**


### 3. Repair
- **Organisms need to repair cells to stay alive and maintain proper health**
- Millions of cells are replaced everyday
- Cells naturally die and need to be replaced
    - e.g., red blood cells, hair cells, skin, injuries, broken bones

### Cell cycle

<img src="https://www2.le.ac.uk/projects/vgec/diagrams/22-Cell-cycle.gif" width="600">

- **Interphase**
    - Large majority of a cell's time is spent in interphase
    - **G1**: (normal growth and function), 
    - Prepare for cell divison
    - **S**: Replication of DNA
    - **G2**: Replication of organelles
    - Checkpoints
        - Cells check various things before progressing through various stages in interphase
        - Causes of stopping via checkpoints include damaged DNA, not replicated DNA, lack of nutrients for cell growth, and/or signals from other cells
- **Mitosis**
    - Occurs only in eukaryotic cells
    - P-MAT: Prophase, Metaphase, Anaphase, Telophase
    - Division of the nucleus
- **Cytokinesis**
    - **cell division**
    - The parent cell splits into two daughter cells
- **G0**
    - Cell no longer divides ("cell cycle arrest")
    - Outside of cell cycle 

### Mitosis
- `Chromatid`: Supercoiled DNA, only visible during mitosis, cannot be read without unwinding, similar to compressed zip file
- `Chromosome`: Two identical "sister chromatids" held together in centre by `centromere`, or one sister chromatid after anaphase
- `Centromere`: Proteins sticking sister chromatids
- PMAT (prophase, metaphase, anaphase, telophase)
- Division of the nucleus

| Phase | Diagram | Description |
| :--- | :--- | :--- |
| Prophase | <img src="http://www.edupic.net/Images/Mitosis/prophase_3D.png" width="250"> | - Chromatin condenses into two identical `sister chromatids` which condense into `chromosomes` <br>      - Happens to 23 pairs of chromosomes <br> - Nuclear membrane dissolves <br> - Centrosomes move to opposite ends (`poles`) of cell, creating `spindle fibres` that begin to attach to `centromeres` in animal cells |
| Metaphase | <img src="http://www.edupic.net/Images/Mitosis/metaphase_3D.png" width="250"> | - Chromosomes line up in centre of cell to ensure they divide evenly <br> - Everything in prophase has completed (e.g., nuclear membrane has dissolved completely) |
| Anaphase | <img src="http://www.edupic.net/Images/Mitosis/anaphase_3D.png" width="250"> | - Centromeres split, separating sister chromatids <br> - Sister chromatids are pulled towards opposite sides of cell via shortening spindle fibres <br>     - Sister chromatids are now called `daughter chromomsomes` |
| Telophase | <img src="http://www.edupic.net/Images/Mitosis/telophase_3D.png" width="250"> | - Effectively opposite of prophase <br> - Nuclear membranes form across each of the two new nuclei <br> - Daughter chromosomes unwind into chromatin and are no longer visible <br> - Nucleolus forms in each nucleus <br> - Spindle fibres break apart <br> - **Cytokinesis** usually begins in telophase <br>     - Cells starts to **cleave** (cell centre starts to pinch itself) |

### Cytokinesis
 - Cell division
 - Cell splits completely to two daughter cells
 - In **animal cells**: Cell membrane pulled inward by cytoskeleton
 - **"Pinches in"** along equator of cell, forming **"cleavage furrow"**
 - In **plant cells**: Golgi apparatus produces and sends vesicles to centre of plant cell **"cell plate"** to make new cell wall and membrane between daughter cells

## Cell Specialization
- `Zygote`: A single-celled organism formed from the fertilization of an egg by a sperm cell, is a totipotent stem cell
- A cell's position in the `gastrula` (outer, middle, inner layer) will determine the fate of the cell, or its potiental. 
- Chemical signals from other cells will also determine activated genes that lead to specialisation
- (LOCATION LOCATION LOCAION!)
- Specialisation is determined by reading only certain genes

### Stem Cells
- They are an **unspecialized** cell that has the potential to become one of several types of cells. 
- Can either divide to two stem cells or one stem cell and one specialised cell
- Specialised cells generally do not divide